#!/bin/bash

# This script replaces plugins with symlinks
# $1 : folder of jars to replace with symlinks
# $2 : folder of jars to be symlinked to
set -e

ECLIPSE_DIR=/usr/lib/eclipse/plugins
JAVA_DIR=/usr/share/java

JMCCORE_DIR=$JAVA_DIR/jmc-core
OWASP_DIR=$JAVA_DIR/owasp-java-encoder
ICU4J_DIR=$JAVA_DIR/icu4j
JAVAMAIL_DIR=$JAVA_DIR/javamail
JAF_DIR=$JAVA_DIR/jaf
HTTPCOMPONENTS_DIR=$JAVA_DIR/httpcomponents

JARS="
org.eclipse.core*.jar
org.eclipse.e4*.jar
org.eclipse.ecf*.jar
org.eclipse.emf*.jar
org.eclipse.equinox.app*.jar
org.eclipse.equinox.bidi*.jar
org.eclipse.equinox.common*.jar
org.eclipse.equinox.concurrent*.jar
org.eclipse.equinox.console*.jar
org.eclipse.equinox.ds*.jar
org.eclipse.equinox.event*.jar
org.eclipse.equinox.frameworkadmin*.jar
org.eclipse.equinox.http*.jar
org.eclipse.equinox.jsp*.jar
org.eclipse.equinox.p2*.jar
org.eclipse.equinox.preferences*.jar
org.eclipse.equinox.registry*.jar
org.eclipse.equinox.security*.jar
org.eclipse.equinox.simpleconfigurator*.jar
org.eclipse.equinox.util*.jar
org.eclipse.help*.jar
org.eclipse.jdt*.jar
org.eclipse.jetty*.jar
org.eclipse.jface*.jar
org.eclipse.osgi*.jar
org.eclipse.rcp*.jar
org.eclipse.swt*.jar
org.eclipse.text*.jar
org.eclipse.ui*.jar
org.eclipse.update*.jar
com.sun.el.javax.el*.jar
javax.el-api*.jar
javax.inject*.jar
javax.servlet-api*.jar
javax.servlet.jsp*.jar
org.apache.batik.constants*.jar
org.apache.batik.css*.jar
org.apache.batik.i18n*.jar
org.apache.batik.util*.jar
org.apache.commons.codec*.jar
org.apache.commons.io*.jar
org.apache.commons.jxpath*.jar
org.apache.commons.logging*.jar
org.apache.felix.gogo.command*.jar
org.apache.felix.gogo.runtime*.jar
org.apache.felix.gogo.shell*.jar
org.apache.felix.scr*.jar
org.apache.lucene.analyzers-common*.jar
org.apache.lucene.analyzers-smartcn*.jar
org.apache.lucene.core*.jar
org.apache.xmlgraphics*.jar
org.glassfish.web.javax.servlet.jsp*.jar
org.kxml2*.jar
org.sat4j.core*.jar
org.sat4j.pb*.jar
org.tukaani.xz*.jar
org.w3c.css.sac*.jar
org.w3c.dom.svg*.jar
org.xmlpull*.jar
"

# these JARs are in subdirectories within JAVA_DIR
JMC_COMMON_JAR="org.openjdk.jmc.common_*.jar"
JMC_JFR_JAR="org.openjdk.jmc.flightrecorder_*.jar"
JMC_JFR_RULES_JAR="org.openjdk.jmc.flightrecorder.rules_*.jar"
JMC_JFR_RULES_JDK_JAR="org.openjdk.jmc.flightrecorder.rules.jdk_*.jar"
OWASP_JAR="org.owasp.encoder*.jar"
ICU4J_JAR="com.ibm.icu_*.jar"
JAVAMAIL_JAR="com.sun.mail.jakarta.mail_*.jar"
JAF_JAR="com.sun.activation.jakarta.activation_*.jar"
JAF_API_JAR="jakarta.activation-api_*.jar"
HTTP_CORE_JAR="org.apache.httpcomponents.httpcore_*.jar"
HTTP_CLIENT_JAR="org.apache.httpcomponents.httpclient_*.jar"
JAVAX_ANNOTAION_JAR="javax.annotation-api*.jar"

# org.eclipse.equinox.launcher determines what launches (don't symlink this jar)

function _sym {
	if [ -f $1 ]
	then
		echo "linking $1 to $2"
		rm -rf $1
		ln -s $2 $1
	else
		echo "failed to link $1 to $2"
		exit 1
	fi
}

for name in ${JARS}; do
	for i in ${name}; do
		echo $i
	done
done

pushd $1
	for name in ${JARS}; do
		for i in ${name}; do
			if [ -e ${ECLIPSE_DIR}/$i ]; then
				echo ${ECLIPSE_DIR}/$i
				_sym $i ${ECLIPSE_DIR}/$i
			elif [ -e ${JAVA_DIR}/$i ]; then
				echo ${JAVA_DIR}/$i
				_sym $i ${JAVA_DIR}/$i
			fi
		done
	done
	for name in ${JMC_COMMON_JAR}; do
		_sym $name ${JMCCORE_DIR}/common.jar
	done
	for name in ${JMC_JFR_JAR}; do
		_sym $name ${JMCCORE_DIR}/flightrecorder.jar
	done
	for name in ${JMC_JFR_RULES_JAR}; do
		_sym $name ${JMCCORE_DIR}/flightrecorder.rules.jar
	done
	for name in ${JMC_JFR_RULES_JDK_JAR}; do
		_sym $name ${JMCCORE_DIR}/flightrecorder.rules.jdk.jar
	done
	for name in ${OWASP_JAR}; do
		_sym $name ${OWASP_DIR}/encoder.jar
	done
	for name in ${ICU4J_JAR}; do
		_sym $name ${ICU4J_DIR}/icu4j.jar
	done
	for name in ${JAVAMAIL_JAR}; do
		_sym $name ${JAVAMAIL_DIR}/jakarta.mail.jar
	done
	for name in ${JAF_JAR}; do
		_sym $name ${JAF_DIR}/jakarta.activation.jar
	done
	for name in ${JAF_API_JAR}; do
		_sym $name ${JAF_DIR}/jakarta.activation-api.jar
	done
	for name in ${HTTP_CORE_JAR}; do
		_sym $name ${HTTPCOMPONENTS_DIR}/httpcore.jar
	done
	for name in ${HTTP_CLIENT_JAR}; do
		_sym $name ${HTTPCOMPONENTS_DIR}/httpclient.jar
	done
	for name in ${JAVAX_ANNOTAION_JAR}; do
		_sym $name ${JAVA_DIR}/glassfish-annotation-api.jar
	done
popd

